@@ -42,8 +42,8 @@
 #' @export
 lsirm1pl_fixed_gamma = function(data, ndim = 2, niter = 15000, nburn = 2500, nthin = 5, nprint = 500,
                                jump_beta = 0.4, jump_theta = 1, jump_z = 0.5, jump_w = 0.5,
-                               pr_mean_beta = 0, pr_sd_beta = 1, pr_mean_theta = 0,
-                               pr_a_theta = 0.001, pr_b_theta = 0.001, verbose=FALSE){
+                               pr_mean_beta = 0, pr_sd_beta = 1, pr_mean_theta = 0, pr_sd_theta = 1,
+                               pr_a_theta = 0.001, pr_b_theta = 0.001, verbose=FALSE, fix_theta_sd=FALSE){
   if(niter < nburn){
     stop("niter must be greater than burn-in process.")
   }
@@ -55,9 +55,10 @@ lsirm1pl_fixed_gamma = function(data, ndim = 2, niter = 15000, nburn = 2500, nth
 
   # cat("\n\nFitting with MCMC algorithm\n")
 
-  output <- lsirm1pl_fixed_gamma_cpp(as.matrix(data), ndim, niter, nburn, nthin, nprint,
-                           jump_beta, jump_theta, jump_z, jump_w,
-                           pr_mean_beta, pr_sd_beta, pr_mean_theta, pr_a_theta, pr_b_theta,verbose=verbose)
+  output <- lsirm1pl_fixed_gamma_cpp(data=as.matrix(data), ndim=ndim, niter=niter, nburn=nburn, nthin=nthin, nprint=nprint,
+                           jump_beta=jump_beta, jump_theta=jump_theta, jump_z=jump_z, jump_w=jump_w,
+                           pr_mean_beta=pr_mean_beta, pr_sd_beta=pr_sd_beta, pr_mean_theta=pr_mean_theta,
+                           pr_sd_theta=pr_sd_theta, pr_a_theta=pr_a_theta, pr_b_theta=pr_b_theta, verbose=verbose, fix_theta_sd=fix_theta_sd)
 
   mcmc.inf = list(nburn=nburn, niter=niter, nthin=nthin)
   nsample <- nrow(data)
