@@ -66,11 +66,11 @@
 #' @export
 lsirm2pl_normal_mar = function(data, ndim = 2, niter = 15000, nburn = 2500, nthin = 5, nprint = 500,
                                jump_beta = 0.4, jump_theta = 1.0, jump_alpha = 1.0, jump_gamma = 1.0, jump_z = 0.5, jump_w = 0.5,
-                               pr_mean_beta = 0, pr_sd_beta = 1.0, pr_mean_theta = 0,
+                               pr_mean_beta = 0, pr_sd_beta = 1.0, pr_mean_theta = 0, pr_sd_theta = 1.0,
                                pr_mean_gamma = 0.5, pr_sd_gamma =1.0,
                                pr_mean_alpha = 0.5, pr_sd_alpha = 1,
                                pr_a_theta = 0.001, pr_b_theta = 0.001,pr_a_eps = 0.001, pr_b_eps = 0.001,
-                               missing.val = 99, verbose=FALSE){
+                               missing.val = 99, verbose=FALSE, fix_theta_sd=FALSE, fix_alpha_1=TRUE){
   if(niter < nburn){
     stop("niter must be greater than burn-in process.")
   }
@@ -83,13 +83,13 @@ lsirm2pl_normal_mar = function(data, ndim = 2, niter = 15000, nburn = 2500, nthi
   # cat("\n\nFitting with MCMC algorithm\n")
 
 
-  output <- lsirm2pl_normal_mar_cpp(as.matrix(data),
-                                    ndim, niter, nburn, nthin, nprint,
-                                    jump_beta, jump_theta, jump_alpha, jump_gamma, jump_z, jump_w,
-                                    pr_mean_beta, pr_sd_beta, pr_a_theta, pr_b_theta, pr_mean_theta,
-                                    pr_a_eps, pr_b_eps,
-                                    pr_mean_gamma, pr_sd_gamma,
-                                    pr_mean_alpha, pr_sd_alpha, missing.val, verbose=verbose)
+  output <- lsirm2pl_normal_mar_cpp(data=as.matrix(data),
+                                    ndim=ndim, niter=niter, nburn=nburn, nthin=nthin, nprint=nprint,
+                                    jump_beta=jump_beta, jump_theta=jump_theta, jump_alpha=jump_alpha, jump_gamma=jump_gamma, jump_z=jump_z, jump_w=jump_w,
+                                    pr_mean_beta=pr_mean_beta, pr_sd_beta=pr_sd_beta, pr_a_theta=pr_a_theta, pr_b_theta=pr_b_theta, pr_mean_theta=pr_mean_theta, pr_sd_theta=pr_sd_theta,
+                                    pr_a_eps=pr_a_eps, pr_b_eps=pr_b_eps,
+                                    pr_mean_gamma=pr_mean_gamma, pr_sd_gamma=pr_sd_gamma,
+                                    pr_mean_alpha=pr_mean_alpha, pr_sd_alpha=pr_sd_alpha, missing=missing.val, verbose=verbose, fix_theta_sd=fix_theta_sd, fix_alpha_1=fix_alpha_1)
 
   mcmc.inf = list(nburn=nburn, niter=niter, nthin=nthin)
   nsample <- nrow(data)
